@@ -38,11 +38,11 @@ class AbstractGeneratorXml(object):
         self.algoritmoSha = None
         self.tipo_objeto = self.data.get('tipo')
         self.version = ''
-        self.cadena_original_value = ''
+        self.__cadena_original = ''
 
     @property
-    def cadena_original(self) -> str:
-        return self.cadena_original_value
+    def cadena_original(self):
+        return self.cadena_original
 
     @abstractmethod
     def generate_xml(self):
@@ -98,10 +98,10 @@ class AbstractGeneratorXml(object):
             certificado_file_pem_bytes = b64decode(certificado_file_pem64)
             key = RSA.importKey(certificado_file_pem_bytes)
             logging.info('OBTENIENDO LA CADENA ORIGINAL DEL XML')
-            self.cadena_original_value = self.get_cadena_original(self.get_xml())
+            self.__cadena_original = self.get_cadena_original(self.get_xml())
             logging.info('LA CADENA ORIGINAL DEL XML')
             digest = self.algoritmoSha.new()
-            digest.update(self.cadena_original_value)
+            digest.update(self.__cadena_original)
             signer = PKCS1_v1_5.new(key)
             sign = signer.sign(digest)
             sello = b64encode(sign)
@@ -116,17 +116,37 @@ class AbstractGeneratorXml(object):
                 xml = xml.encode('utf-8')
             xml = etree.fromstring(xml)
             logging.info('PARSE DE LA CADENA ORIGINAL DEL XML')
-            logging.info(self.dir_xml)
-            xslt = etree.parse(self.dir_xml + '/cadenaoriginal_3_3_local/cadenaoriginal_3_3.xslt')
+            url = 'http://www.sat.gob.mx/sitio_internet/cfd/3/cadenaoriginal_3_3/cadenaoriginal_3_3.xslt'
+            res = None
+            try:
+                res = requests.get(url, timeout=240, stream=True)
+            except (requests.exceptions.Timeout, requests.exceptions.ConnectionError) as e:
+                logging.error(u"Hubo un error en el servidor del SAT, por favor intente mas tarde: " + str(e))
+                raise Exception(u"Hubo un error en el servidor del SAT, por favor intente mas tarde: " + str(e))
+            except Exception as e:
+                logging.error(u"Hubo un error en el servidor del SAT, por favor intente mas tarde: " + str(e))
+                raise Exception(u"Hubo un error en el servidor del SAT, por favor intente mas tarde: " + str(e))
+            if res is None:
+                logging.error(u"Hubo un error en el servidor del SAT, por favor intente mas tarde.")
+                raise Exception(u"Hubo un error en el servidor del SAT, por favor intente mas tarde.")
+            elif res.content is None:
+                logging.error(u"Hubo un error en el servidor del SAT, por favor intente mas tarde.")
+                raise Exception(u"Hubo un error en el servidor del SAT, por favor intente mas tarde.")
+            elif res.content is b'' or len(res.content) == 0:
+                logging.error(u"Hubo un error en el servidor del SAT, por favor intente mas tarde.")
+                raise Exception(u"Hubo un error en el servidor del SAT, por favor intente mas tarde.")
+            xslt = etree.fromstring(res.content)
             logging.info('XSLT CADENA ORIGINAL DEL XML')
             parser = etree.XSLT(xslt)
             logging.info('XSLT CADENA ORIGINAL DEL XML 2')
-            cadena_original = parser(xml)
+            self.__cadena_original = parser(xml)
             logging.info('XSLT CADENA ORIGINAL DEL XML 3')
-            return cadena_original
+            return self.__cadena_original
+            # else:
+            #     raise ('Error with cadenaoriginal_3_3.xslt')
         except XSLTParseError as e:
-            logging.error(u"Hubo un error al generar la cadena original, por favor intente mas tarde: " + str(e))
-            raise Exception(u"Hubo un error al generar la cadena original, por favor intente mas tarde: " + str(e))
+            logging.error(u"Hubo un error en el servidor del SAT, por favor intente mas tarde: " + str(e))
+            raise Exception(u"Hubo un error en el servidor del SAT, por favor intente mas tarde: " + str(e))
         except Exception as e:
             logging.error('Error al leer el archivo: cadenaoriginal_' + self.data.get('version') + '.xslt:' + str(e))
             raise Exception(e)
